@@ -83,7 +83,7 @@ void AbstractParameter::extractPositionFromKeypointList(KeypointList &) {}
 
 AbstractParameter * AbstractParameter::createFromText(const char * text, int & length, QString & error, QWidget * parent)
 {
-  AbstractParameter * result = 0;
+  AbstractParameter * result = nullptr;
   QString line = text;
   error.clear();
 
@@ -214,7 +214,7 @@ QStringList AbstractParameter::parseText(const QString & type, const char * text
   }
 
   QString open = re.cap(2);
-  const char * end = 0;
+  const char * end = nullptr;
   if (open == "(") {
     end = strstr(text + prefixLength, ")");
   } else if (open == "{") {
@@ -222,6 +222,10 @@ QStringList AbstractParameter::parseText(const QString & type, const char * text
   } else if (open == "[") {
     end = strstr(text + prefixLength, "]");
   }
+  if (!end) {
+    Logger::log(QString("[gmic-qt] Parse error in %1 parameter.").arg(type));
+    return QStringList();
+  }
   QString values = str.mid(prefixLength, -1).left(end - (text + prefixLength)).trimmed();
   length = 1 + end - text;
 
