@@ -22,8 +22,8 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_CONSTPARAMETER_H_
-#define _GMIC_QT_CONSTPARAMETER_H_
+#ifndef GMIC_QT_CONSTPARAMETER_H
+#define GMIC_QT_CONSTPARAMETER_H
 
 #include "AbstractParameter.h"
 class QLabel;
@@ -45,4 +45,4 @@ private:
   QString _value;
 };
 
-#endif // _GMIC_QT_CONSTPARAMETER_H_
+#endif // GMIC_QT_CONSTPARAMETER_H
