@@ -22,8 +22,8 @@
  *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#ifndef _GMIC_QT_KEYPOINTLIST_H_
-#define _GMIC_QT_KEYPOINTLIST_H_
+#ifndef GMIC_QT_KEYPOINTLIST_H
+#define GMIC_QT_KEYPOINTLIST_H
 
 #include <QColor>
 #include <QPointF>
@@ -61,7 +61,6 @@ public:
   QPointF position(int n) const;
   QColor color(int n) const;
   bool isRemovable(int n) const;
-  bool allowsBusrt(int n) const;
 
   typedef std::deque<Keypoint>::iterator iterator;
   typedef std::deque<Keypoint>::const_iterator const_iterator;
@@ -111,4 +110,4 @@ int KeypointList::Keypoint::actualRadiusFromPreviewSize(const QSize & size) cons
   }
 }
 
-#endif // _GMIC_QT_KEYPOINTLIST_H_
+#endif // GMIC_QT_KEYPOINTLIST_H
