@@ -7,7 +7,7 @@
 <context>
     <name>ColorParameter</name>
     <message>
-        <location filename="../src/FilterParameters/ColorParameter.cpp" line="132"/>
+        <location filename="../src/FilterParameters/ColorParameter.cpp" line="133"/>
         <source>Select color</source>
         <translation>Selecteer een kleur</translation>
     </message>
@@ -20,173 +20,198 @@
         <translation>Instellingen</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="102"/>
+        <location filename="../ui/dialogsettings.ui" line="221"/>
         <source>Internet updates</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="111"/>
+        <location filename="../ui/dialogsettings.ui" line="230"/>
         <source>Update now</source>
         <translation>Nu updaten</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="140"/>
+        <location filename="../ui/dialogsettings.ui" line="30"/>
         <source>Layout</source>
         <translation>Lay-out</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="204"/>
+        <location filename="../ui/dialogsettings.ui" line="24"/>
+        <source>Interface</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="64"/>
         <source>Preview on the &amp;left</source>
         <translation>Preview aan &amp;linkerzijde</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="167"/>
+        <location filename="../ui/dialogsettings.ui" line="94"/>
         <source>Pre&amp;view on right side</source>
         <translation>Preview aan &amp;rechterzijde</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="24"/>
+        <location filename="../ui/dialogsettings.ui" line="113"/>
         <source>Theme</source>
         <translation>Thema</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="30"/>
+        <location filename="../ui/dialogsettings.ui" line="119"/>
         <source>&amp;Default</source>
         <translation>&amp;standaard</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="37"/>
+        <location filename="../ui/dialogsettings.ui" line="126"/>
         <source>Dar&amp;k</source>
         <translation>&amp;Donker</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="50"/>
+        <location filename="../ui/dialogsettings.ui" line="139"/>
         <source>&lt;i&gt;(Restart needed)&lt;/I&gt;</source>
         <translation>&lt;i&gt;(Opnieuw opstarten nodig)&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="60"/>
+        <location filename="../ui/dialogsettings.ui" line="149"/>
         <source>Language</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="72"/>
-        <location filename="../src/DialogSettings.cpp" line="77"/>
+        <location filename="../ui/dialogsettings.ui" line="179"/>
+        <source>Always enable preview zooming</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="186"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;(Warning: preview may be inaccurate&lt;br/&gt;if checked.)&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="215"/>
+        <source>Other</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="253"/>
+        <location filename="../src/DialogSettings.cpp" line="84"/>
         <source>Output messages</source>
         <translation>Uitvoer berichten</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="84"/>
+        <location filename="../ui/dialogsettings.ui" line="196"/>
         <source>Dialogs</source>
         <translation>Dialoogvenster</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="90"/>
+        <location filename="../ui/dialogsettings.ui" line="202"/>
         <source>Use native color dialog</source>
         <translation>Gebruik standaard kleur in dialoogvenster</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="121"/>
+        <location filename="../ui/dialogsettings.ui" line="163"/>
         <source>Preview</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="127"/>
+        <location filename="../ui/dialogsettings.ui" line="169"/>
         <source>Timeout (seconds)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="176"/>
+        <location filename="../ui/dialogsettings.ui" line="36"/>
         <source>Show institution logos</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="240"/>
+        <location filename="../ui/dialogsettings.ui" line="262"/>
+        <source>Notify when scheduled update fails</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="304"/>
         <source>&amp;Ok</source>
         <translation>&amp;Ok</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="57"/>
+        <location filename="../src/DialogSettings.cpp" line="64"/>
         <source>Settings</source>
         <translation>Instellingen</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="63"/>
+        <location filename="../src/DialogSettings.cpp" line="70"/>
         <source>Never</source>
         <translation>Nooit</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="64"/>
+        <location filename="../src/DialogSettings.cpp" line="71"/>
         <source>Daily</source>
         <translation>Dagelijks</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="65"/>
+        <location filename="../src/DialogSettings.cpp" line="72"/>
         <source>Weekly</source>
         <translation>Weekelijks</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="66"/>
+        <location filename="../src/DialogSettings.cpp" line="73"/>
         <source>Every 2 weeks</source>
         <translation>Elke twee weken</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="67"/>
+        <location filename="../src/DialogSettings.cpp" line="74"/>
         <source>Monthly</source>
         <translation>Maandelijks</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="69"/>
+        <location filename="../src/DialogSettings.cpp" line="76"/>
         <source>At launch (debug)</source>
         <translation>Bij opstarten (debug)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="78"/>
+        <location filename="../src/DialogSettings.cpp" line="85"/>
         <source>Output messages...</source>
         <translation>Uitvoer berichten...</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="79"/>
+        <location filename="../src/DialogSettings.cpp" line="86"/>
         <source>Quiet (default)</source>
         <translation>Geen bericht (standaard)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="80"/>
+        <location filename="../src/DialogSettings.cpp" line="87"/>
         <source>Verbose (layer name)</source>
         <translation>Uitgebreid (laag-naam)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="81"/>
+        <location filename="../src/DialogSettings.cpp" line="88"/>
         <source>Verbose (console)</source>
         <translation>Uitgebreid (console)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="82"/>
+        <location filename="../src/DialogSettings.cpp" line="89"/>
         <source>Verbose (log file)</source>
         <translation>Uitgebreid (logbestand)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="83"/>
+        <location filename="../src/DialogSettings.cpp" line="90"/>
         <source>Very verbose (console)</source>
         <translation>Zeer uitgebreid (console)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="84"/>
+        <location filename="../src/DialogSettings.cpp" line="91"/>
         <source>Very verbose (log file)</source>
         <translation>Zeer uitgebreid (logbestand)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="85"/>
+        <location filename="../src/DialogSettings.cpp" line="92"/>
         <source>Debug (console)</source>
         <translation>Debug (console)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="86"/>
+        <location filename="../src/DialogSettings.cpp" line="93"/>
         <source>Debug (log file)</source>
         <translation>Debug (logbestand)</translation>
     </message>
     <message>
-        <location filename="../src/DialogSettings.cpp" line="102"/>
+        <location filename="../src/DialogSettings.cpp" line="109"/>
         <source>Check to use Native/OS color dialog, uncheck to use Qt&apos;s</source>
         <translation>Aan voor standaard OS-kleur omgeving, Uit voor QT-kleur</translation>
     </message>
@@ -194,9 +219,9 @@
 <context>
     <name>FileParameter</name>
     <message>
-        <location filename="../src/FilterParameters/FileParameter.cpp" line="140"/>
-        <location filename="../src/FilterParameters/FileParameter.cpp" line="143"/>
-        <location filename="../src/FilterParameters/FileParameter.cpp" line="146"/>
+        <location filename="../src/FilterParameters/FileParameter.cpp" line="148"/>
+        <location filename="../src/FilterParameters/FileParameter.cpp" line="151"/>
+        <location filename="../src/FilterParameters/FileParameter.cpp" line="154"/>
         <source>Select a file</source>
         <translation>Selecteer een bestand</translation>
     </message>
@@ -204,24 +229,33 @@
 <context>
     <name>FilterParametersWidget</name>
     <message>
-        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="38"/>
-        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="147"/>
+        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="39"/>
+        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="172"/>
         <source>&lt;i&gt;Select a filter&lt;/i&gt;</source>
         <translation type="unfinished">&lt;i&gt;Selecteer een filter&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="116"/>
+        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="139"/>
         <source>&lt;i&gt;No parameters&lt;/i&gt;</source>
         <translation type="unfinished">&lt;i&gt;Geen parameters&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="121"/>
+        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="144"/>
         <source>Error parsing filter parameters
 
 </source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>FiltersPresenter</name>
+    <message>
+        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="411"/>
+        <source>Cannot find this fave&apos;s original filter
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>FiltersView</name>
     <message>
@@ -236,7 +270,7 @@
     </message>
     <message>
         <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="66"/>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="332"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="338"/>
         <source>Remove fave</source>
         <translation type="unfinished">Verwijder favoriet</translation>
     </message>
@@ -251,7 +285,7 @@
         <translation type="unfinished">Voeg favoriet toe</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="332"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="338"/>
         <source>Do you really want to remove the following fave?
 
 %1
@@ -262,7 +296,7 @@
 <context>
     <name>FolderParameter</name>
     <message>
-        <location filename="../src/FilterParameters/FolderParameter.cpp" line="118"/>
+        <location filename="../src/FilterParameters/FolderParameter.cpp" line="126"/>
         <source>Select a folder</source>
         <translation>Selecteer een map</translation>
     </message>
@@ -293,136 +327,131 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/inoutpanel.ui" line="112"/>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="44"/>
+        <location filename="../ui/inoutpanel.ui" line="102"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="45"/>
         <source>Input layers</source>
         <translation>Invoer lagen</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="45"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="46"/>
         <source>None</source>
         <translation>Geen</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="46"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="47"/>
         <source>Active (default)</source>
         <translation>Actief (standaard)</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="47"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="48"/>
         <source>All</source>
         <translation>Alle</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="48"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="49"/>
         <source>Active and below</source>
         <translation>Actief en daaronder</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="49"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="50"/>
         <source>Active and above</source>
         <translation>Actief en daarboven</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="50"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="51"/>
         <source>All visible</source>
         <translation>Alle zichtbare lagen</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="51"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="52"/>
         <source>All invisible</source>
         <translation>Alle onzichtbare lagen</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="52"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="53"/>
         <source>All visible (decr.)</source>
         <translation>Alle zichtbare lagen (dalend)</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="53"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="54"/>
         <source>All invisible (decr.)</source>
         <translation>Alle onzichtbare lagen (dalend)</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="54"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="55"/>
         <source>All (decr.)</source>
         <translation>Alle (dalend)</translation>
     </message>
     <message>
-        <location filename="../ui/inoutpanel.ui" line="158"/>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="56"/>
+        <location filename="../ui/inoutpanel.ui" line="138"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="57"/>
         <source>Output mode</source>
         <translation>Uitvoer-modus</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="57"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="58"/>
         <source>In place (default)</source>
         <translation>In plaats van (standaard)</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="58"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="59"/>
         <source>New layer(s)</source>
         <translation>Nieuwe laag/lagen</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="59"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="60"/>
         <source>New active layer(s)</source>
         <translation>Nieuwe actieve laag/lagen</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="60"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="61"/>
         <source>New image</source>
         <translation>Nieuwe afbeelding</translation>
     </message>
     <message>
-        <location filename="../ui/inoutpanel.ui" line="89"/>
-        <source>Output messages</source>
-        <translation>Uitvoer berichten</translation>
-    </message>
-    <message>
-        <location filename="../ui/inoutpanel.ui" line="135"/>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="62"/>
+        <location filename="../ui/inoutpanel.ui" line="125"/>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="63"/>
         <source>Preview mode</source>
         <translation>Preview-modus</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="63"/>
-        <source>1st ouput (default)</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="64"/>
+        <source>1st output (default)</source>
         <translation>1ste afbeelding (standaard)</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="64"/>
-        <source>2nd ouput</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="65"/>
+        <source>2nd output</source>
         <translation>2de afbeelding</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="65"/>
-        <source>3rd ouput</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="66"/>
+        <source>3rd output</source>
         <translation>3de afbeelding</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="66"/>
-        <source>4th ouput</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="67"/>
+        <source>4th output</source>
         <translation>4de afbeelding</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="67"/>
-        <source>1st -&gt; 2nd ouput</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="68"/>
+        <source>1st -&gt; 2nd output</source>
         <translation>1ste -&gt; 2de afbeelding</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="68"/>
-        <source>1st -&gt; 3rd ouput</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="69"/>
+        <source>1st -&gt; 3rd output</source>
         <translation>1ste -&gt; 3de afbeelding</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="69"/>
-        <source>1st -&gt; 4th ouput</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="70"/>
+        <source>1st -&gt; 4th output</source>
         <translation>1ste -&gt; 4de afbeelding</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/InOutPanel.cpp" line="70"/>
-        <source>All ouputs</source>
+        <location filename="../src/Widgets/InOutPanel.cpp" line="71"/>
+        <source>All outputs</source>
         <translation>Alle afbeeldingen</translation>
     </message>
 </context>
@@ -452,12 +481,12 @@
         <translation>GMIC</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="155"/>
+        <location filename="../ui/mainwindow.ui" line="161"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Download filter definitions from remote sources&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Download filter-definities van afzonderlijke bronnen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="158"/>
+        <location filename="../ui/mainwindow.ui" line="164"/>
         <source>Internet</source>
         <translation>Internet</translation>
     </message>
@@ -467,70 +496,50 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="532"/>
+        <location filename="../ui/mainwindow.ui" line="489"/>
         <source>TextLabel</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="227"/>
+        <location filename="../ui/mainwindow.ui" line="233"/>
         <source>...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="370"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enable/disable preview&lt;br/&gt;(right click on preview image for instant swaping)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Inschakelen/uitschakelen preview l&apos;aperçu&lt;br/&gt;(rechtermuisklik in preview-vak voor omwisselen)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <location filename="../ui/mainwindow.ui" line="379"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enable/disable preview&lt;br/&gt;(Ctrl+P)&lt;br/&gt;(right click on preview image for instant swapping)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="373"/>
+        <location filename="../ui/mainwindow.ui" line="382"/>
         <source>Preview</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="516"/>
+        <location filename="../ui/mainwindow.ui" line="473"/>
         <source>Settings...</source>
         <translation>Instellingen...</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="545"/>
+        <location filename="../ui/mainwindow.ui" line="502"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Annuleer</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="558"/>
+        <location filename="../ui/mainwindow.ui" line="515"/>
         <source>&amp;Fullscreen</source>
         <translation>&amp;Schermvullend</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="571"/>
+        <location filename="../ui/mainwindow.ui" line="528"/>
         <source>&amp;Apply</source>
         <translation>&amp;Toepassen</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="584"/>
+        <location filename="../ui/mainwindow.ui" line="541"/>
         <source>&amp;OK</source>
         <translation></translation>
     </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="77"/>
-        <source>Zoom in</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="78"/>
-        <source>Zoom out</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="79"/>
-        <source>Reset zoom</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/MainWindow.cpp" line="81"/>
-        <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="82"/>
         <source>Add fave</source>
@@ -543,7 +552,7 @@
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="87"/>
-        <source>Update filters</source>
+        <source>Update filters (Ctrl+R / F5)</source>
         <translation></translation>
     </message>
     <message>
@@ -563,68 +572,73 @@
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="97"/>
-        <source>G&apos;MIC (http://gmic.eu)&lt;br/&gt;GREYC (http://www.greyc.fr)&lt;br/&gt;CNRS (http://www.cnrs.fr)&lt;br/&gt;Normandy University (http://www.unicaen.fr)&lt;br/&gt;Ensicaen (http://www.ensicaen.fr)</source>
-        <translation>G&apos;MIC (http://gmic.eu)&lt;br/&gt;GREYC (http://www.greyc.fr)&lt;br/&gt;CNRS (http://www.cnrs.fr)&lt;br/&gt;Normandie Universiteit (http://www.unicaen.fr)&lt;br/&gt;Ensicaen (http://www.ensicaen.fr)</translation>
+        <source>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandy University (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</source>
+        <translation>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandie Universiteit (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="263"/>
+        <location filename="../src/MainWindow.cpp" line="287"/>
         <source>Update completed</source>
         <translation>Update voltooid</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="263"/>
-        <location filename="../src/MainWindow.cpp" line="265"/>
-        <location filename="../src/MainWindow.cpp" line="316"/>
+        <location filename="../src/MainWindow.cpp" line="287"/>
+        <location filename="../src/MainWindow.cpp" line="289"/>
+        <location filename="../src/MainWindow.cpp" line="343"/>
         <source>Filter definitions have been updated.</source>
         <translation>De filter-definities zijn bijgewerkt.</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="268"/>
+        <location filename="../src/MainWindow.cpp" line="292"/>
         <source>No download was needed.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="447"/>
+        <location filename="../src/MainWindow.cpp" line="339"/>
+        <source>Filters update could not be achieved</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="461"/>
         <source>The update could not be achieved&lt;br&gt;because of the following errors:&lt;br&gt;</source>
         <translation>De update is mislukt&lt;br/&gt;vanwege de volgende fouten:&lt;br/&gt;</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="453"/>
+        <location filename="../src/MainWindow.cpp" line="467"/>
         <source>Update error</source>
         <translation>Update fout</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="596"/>
+        <location filename="../src/MainWindow.cpp" line="650"/>
         <source>Error</source>
         <translation>Fout</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="675"/>
+        <location filename="../src/MainWindow.cpp" line="742"/>
         <source>Waiting for cancelled jobs...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1004"/>
+        <location filename="../src/MainWindow.cpp" line="1078"/>
         <source>Import faves</source>
         <translation>Importeer favorieten</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1004"/>
+        <location filename="../src/MainWindow.cpp" line="1078"/>
         <source>Do you want to import faves from file below?&lt;br/&gt;%1</source>
         <translation>Wilt u favorieten importeren van het bestand hieronder?&lt;br/&gt;%1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1007"/>
+        <location filename="../src/MainWindow.cpp" line="1081"/>
         <source>Don&apos;t ask again</source>
         <translation>Niet opnieuw vragen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1096"/>
+        <location filename="../src/MainWindow.cpp" line="1193"/>
         <source>Confirmation</source>
         <translation>Bevestiging</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1096"/>
+        <location filename="../src/MainWindow.cpp" line="1193"/>
         <source>A gmic command is running.&lt;br&gt;Do you really want to close the plugin?</source>
         <translation>GMIC voert momenteel een commando uit.&lt;br&gt;Wilt u echt afbreken?</translation>
     </message>
@@ -656,7 +670,7 @@
     </message>
     <message>
         <location filename="../ui/progressinfowidget.ui" line="48"/>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="46"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="48"/>
         <source>Abort</source>
         <translation>Annuleer</translation>
     </message>
@@ -666,23 +680,23 @@
         <translation>TextLabel</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="43"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="45"/>
         <source>G&apos;MIC-Qt Plug-in progression</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="141"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="143"/>
         <source>Updating filters...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="196"/>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="209"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="198"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="211"/>
         <source>[Processing %1 | %2]</source>
         <translation>[Verwerken %1 | %2]</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="211"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="213"/>
         <source>[Processing %1]</source>
         <translation>[Verwerken %1]</translation>
     </message>
@@ -706,17 +720,17 @@
         <translation>Annuleren</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="103"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="134"/>
         <source>%1 seconds</source>
         <translation>%1 seconden</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="113"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="144"/>
         <source>[Processing %1 | %2]</source>
         <translation>|Verwerken %1 | %2]</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="115"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="146"/>
         <source>[Processing %1]</source>
         <translation>|Verwerken %1]</translation>
     </message>
@@ -724,27 +738,27 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="81"/>
+        <location filename="../src/Host/None/host_none.cpp" line="82"/>
         <source>Select an image to open...</source>
         <translation>Selecteer een afbeelding om te openen...</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="81"/>
+        <location filename="../src/Host/None/host_none.cpp" line="82"/>
         <source>PNG &amp; JPG files (*.png *.jpeg *.jpg *.PNG *.JPEG *.JPG)</source>
         <translation>PNG &amp; JPG bestanden (*.png *.jpeg *.jpg *.PNG *.JPEG *.JPG)</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="87"/>
+        <location filename="../src/Host/None/host_none.cpp" line="88"/>
         <source>Error</source>
         <translation>Fout</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="87"/>
+        <location filename="../src/Host/None/host_none.cpp" line="88"/>
         <source>Could not open file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="91"/>
+        <location filename="../src/Host/None/host_none.cpp" line="92"/>
         <source>Default image</source>
         <translation type="unfinished"></translation>
     </message>
@@ -767,12 +781,12 @@
         <translation>Frame</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="72"/>
+        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="76"/>
         <source>Search</source>
         <translation>Zoek</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="73"/>
+        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="77"/>
         <source>Search in filters list (%1)</source>
         <translation>Zoek in lijst met filters (%1)</translation>
     </message>
@@ -780,32 +794,32 @@
 <context>
     <name>Updater</name>
     <message>
-        <location filename="../src/Updater.cpp" line="206"/>
+        <location filename="../src/Updater.cpp" line="208"/>
         <source>Could not read/decompress %1</source>
         <translation>Niet leesbaar/uitpakbaar %1</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="197"/>
+        <location filename="../src/Updater.cpp" line="199"/>
         <source>Error downloading %1 (empty file?)</source>
         <translation>Downloadfout %1 (fichier vide ?)</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="212"/>
+        <location filename="../src/Updater.cpp" line="214"/>
         <source>Error creating file %1</source>
         <translation>Kan bestand niet maken %1</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="216"/>
+        <location filename="../src/Updater.cpp" line="218"/>
         <source>Error writing file %1</source>
         <translation>Kan bestand niet schrijven %1</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="228"/>
-        <source>Error downloading %1</source>
-        <translation>Downloadfout %1</translation>
+        <location filename="../src/Updater.cpp" line="235"/>
+        <source>Error downloading %1&lt;br/&gt;Error %2: %3</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="256"/>
+        <location filename="../src/Updater.cpp" line="268"/>
         <source>Download timeout: %1</source>
         <translation></translation>
     </message>
@@ -813,9 +827,29 @@
 <context>
     <name>ZoomLevelSelector</name>
     <message>
-        <location filename="../ui/zoomlevelselector.ui" line="14"/>
+        <location filename="../ui/zoomlevelselector.ui" line="20"/>
         <source>Form</source>
         <translation type="unfinished">GMIC</translation>
     </message>
+    <message>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="51"/>
+        <source>Zoom in</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="52"/>
+        <source>Zoom out</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="53"/>
+        <source>Reset zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="153"/>
+        <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
